@@ -189,19 +189,28 @@ class Module:
         self.subscribe_mqtt(f"$iothub/methods/POST/{name}/#", handler)
 
     def subscribe(self, type: str, cb):
+        [channel, mtype] = type.split("/")
+        if not mtype:
+            channel = 'message'
+            mtype = channel
+
         def handler(topic: str, payload):
             args = json.loads(payload)
             type = topic.split("/")[3]
             cb(args, type)
 
-        self.subscribe_mqtt(f"ombori/grid/message/{type}", handler)
+        self.subscribe_mqtt(f"ombori/grid/{mtype}/{mtype}", handler)
 
     def on_event(self, type: str, cb):
         self.subscribe(type, cb)
 
     def publish(self, type: str, payload):
+        [channel, mtype] = type.split("/")
+        if not mtype:
+            channel = 'message'
+            mtype = channel
         data = json.dumps(payload)
-        self.publish_mqtt(f"ombori/grid/message/{type}", data)
+        self.publish_mqtt(f"ombori/grid/{channel}/{type}", data)
 
     def broadcast(self, type: str, payload):
         self.publish(type, payload)
